==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Import SVG</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pliki SVG</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation type="unfinished">Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">SVG Import ...</translation>
    </message>
    <message>
        <location filename="../SvgImport.js" line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Importowanie SVG</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pliki SVG</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Importuj &amp;SVG...</translation>
    </message>
    <message>
        <location filename="../SvgImport.js" line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation>Importowanie SVG</translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation>Rozdzielczość:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation>Liczba pikseli / cal</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation>Splajny</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation>Automatyczne konwertowanie splajnów na linie / łuki jeśli jest to możliwe</translation>
    </message>
</context>
</TS>
